# Bert Schemas

[![License: Apache](https://img.shields.io/badge/License-Apache-yellow.svg)](https://opensource.org/licenses/Apache-2.0) [![Twitter](https://img.shields.io/twitter/url/https/twitter.com/Infleqtion.svg?style=social&label=Follow%20%40Infleqtion)](https://twitter.com/Infleqtion)

## 🚀 Quick Install

```python
pip install bert-schemas
```

## 🧭 Introduction

These Pydantic schemas are used by projects such as Oqtant for defining and validating REST payloads.
